// require plugins
const gulp = require('gulp');
const plumber = require('gulp-plumber');
const changed = require('gulp-changed');
const pug = require('gulp-pug');
const sass = require('gulp-sass');
const autoprefixer = require('gulp-autoprefixer');
const cleancss = require('gulp-clean-css');
const babel = require('gulp-babel');
const uglify = require('gulp-uglify');
const sourcemaps = require('gulp-sourcemaps');
const browsersync = require('browser-sync').create();

// html task
function htmlTask(src, dest) {
  gulp.src(src)
    .pipe(plumber())
    .pipe(changed(dest, {extension: '.html'}))
    .pipe(pug({pretty: true}))
    .pipe(gulp.dest(dest))
    .pipe(browsersync.stream({match: '**/*.html'}));
}

gulp.task('html', function() {
  htmlTask('./*.pug', './');
});

// css task
function cssTask(src, dest) {
  gulp.src(src)
    .pipe(plumber())
    .pipe(changed(dest, {extension: '.css'}))
    .pipe(sass())
    .pipe(autoprefixer({browsers: ['last 4 versions']}))
    .pipe(sourcemaps.init())
    .pipe(cleancss())
    .pipe(sourcemaps.write('.'))
    .pipe(gulp.dest(dest))
    .pipe(browsersync.stream({match: '**/*.css'}));
}

gulp.task('css', function() {
  cssTask('./src/*.scss', './dist/');
});

// js task
function jsTask(src, dest) {
  gulp.src(src)
    .pipe(plumber())
    .pipe(changed(dest, {extension: '.js'}))
    .pipe(babel({presets: ['env']}))
    .pipe(sourcemaps.init())
    .pipe(uglify())
    .pipe(sourcemaps.write('.'))
    .pipe(gulp.dest(dest))
    .pipe(browsersync.stream({match: '**/*.js'}));
}

gulp.task('js', function() {
  jsTask('./src/*.js', './dist/');
});

// start server
gulp.task('server', function() {
  browsersync.init({
    open: false,
    server: './' // static server
  });
});

// watch task
gulp.task('watch', function() {
  gulp.watch('./*.pug', ['html']);
  gulp.watch('./src/**/*.scss', ['css']);
  gulp.watch('./src/**/*.js', ['js']);
});

// default task
gulp.task('default', ['server', 'watch']);
