/*!
 * Fund Card
 * https://github.com/dahjson/fund-card
 * Copyright (c) Daniel Johnson
 */

!function($) { // avoid conflicts
  'use_strict';

  // plugin class
  class FundCard {
    constructor(element, options) {
      // setup plugin settings
      this.element = element;
      this.image = this.element.data('image') || options.image;
      this.title = this.element.data('title') || options.title;
      this.raised = this.element.data('raised') || options.raised;
      this.percent = this.element.data('percent') || options.percent;
      this.color = this.element.data('color') || options.color;
      this.button = this.element.data('button') || options.button;
      this.link = this.element.data('link') || options.link;

      // convert strings to numbers
      this.raised = this.addCommas(parseFloat(this.raised).toFixed(2));
      this.percent = parseInt(this.percent);

      // create project card
      this.card_element = $('<div>').addClass('fund-card__card').insertAfter(this.element);
      this.image_element = $('<div>').addClass('fund-card__image').appendTo(this.card_element);
      this.content_element = $('<div>').addClass('fund-card__content').appendTo(this.card_element);
      this.title_element = $('<div>').addClass('fund-card__title').appendTo(this.content_element);
      this.raised_element = $('<div>').addClass('fund-card__raised').appendTo(this.content_element);
      this.progress_element = $('<div>').addClass('fund-card__progress').appendTo(this.content_element);
      this.start_element = $('<div>0%</div>').addClass('fund-card__start').appendTo(this.progress_element);
      this.end_element = $('<div>100%</div>').addClass('fund-card__end').appendTo(this.progress_element);
      this.percent_element = $('<div>').addClass('fund-card__percent').appendTo(this.progress_element);
      this.button_element = $('<a href="">').addClass('fund-card__btn').appendTo(this.content_element);

      // add data to elements
      this.image_element.html(`<img src="${this.image}" alt=${this.title}>`);
      this.title_element.text(this.title);
      this.raised_element.html(`$${this.raised}<span>Raised</span>`).css('color', this.color);
      this.percent_element.css('width', this.percent + '%').css('background', this.color);
      this.button_element.text(this.button).css('background', this.color).attr('href', this.link);
    }

    // add commas to number
    addCommas(num) {
      return num.replace(/(\d)(?=(\d\d\d)+(?!\d))/g, "$1,");
    }
  }

  // jQuery plugin
  $.fn.fundCard = function(options) {
    // default options for plugin
    const defaults = {
      image: '',
      title: '',
      raised: 0,
      percent: 0,
      color: '#333',
      button: 'Give',
      link: ''
    };

    // merge defaults with user defaults and options
    const settings = $.extend({}, defaults, $.fn.fundCard.defaults, options);

    // instantiate class instance
    return new FundCard($(this), settings);
  };

  // execute code
  $(function() {
    // attach to elements with class name
    $('.fund-card').each(function() {
      $(this).fundCard();
    });
  });
}(jQuery);
